﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using System.Windows.Forms.DataVisualization.Charting;

namespace WinformChart.Control
{
	public partial class ChartControl : UserControl
	{
		public Chart Chart { get; private set; }

		public string Title
		{
			get 
			{
				if (chart.Titles.Count < 1)
					return "";

				return chart.Titles[0].Text; 
			}
			set
			{
				if (string.IsNullOrEmpty(value))
					chart.Titles.Clear();
				else if (chart.Titles.Count < 1)
					chart.Titles.Add(value);
				else
					chart.Titles[0].Text = value;
			}
		}

		public ChartControl()
		{
			InitializeComponent();

			InitInstance();
		}

		private void InitInstance()
		{
			this.Chart = chart;
		}

		public void SetChartType(string seriesName, SeriesChartType type)
		{
			Series series = chart.Series.FindByName(seriesName);
			if (series == null)
				return;

			series.ChartType = type;
		}

		public void SetSeries(string seriesName, ChartValueType type = ChartValueType.Auto)
		{
			Series series = chart.Series.FindByName(seriesName);
			if (series == null)
			{
				chart.Series.Add(new Series(seriesName));

				series = chart.Series.FindByName(seriesName);
				series.XValueType = type;
			}
		}

		public void Add(string seriesName, DateTime x, double y, double span = 3d)
		{
			Series series = chart.Series.FindByName(seriesName);
			if (series == null)
			{
				chart.Series.Add(new Series(seriesName));
				series = chart.Series.FindByName(seriesName);
			}

			if (series.Points.Count < 1)
			{
				DateTime now = DateTime.Now;
				chart.ChartAreas[0].AxisX.Minimum = now.ToOADate();
				chart.ChartAreas[0].AxisX.Maximum = now.AddSeconds(span).ToOADate();
				chart.ChartAreas[0].AxisX.LabelStyle.Format = "HH:mm:ss";
				chart.ChartAreas[0].AxisX.IsLabelAutoFit = false;
				chart.ChartAreas[0].AxisY.IsLabelAutoFit = false;
				chart.ChartAreas[0].InnerPlotPosition.Auto = false;
				chart.ChartAreas[0].InnerPlotPosition.X = 10;
				chart.ChartAreas[0].InnerPlotPosition.Y = 10;
				chart.ChartAreas[0].InnerPlotPosition.Width = 80;
				chart.ChartAreas[0].InnerPlotPosition.Height = 80;


			}


			if (x.ToOADate() > chart.ChartAreas[0].AxisX.Maximum)
			{
				chart.ChartAreas[0].AxisX.Minimum = x.AddSeconds(-1 * span).ToOADate();
				chart.ChartAreas[0].AxisX.Maximum = x.ToOADate();
			}

			series.Points.AddXY(x, y);
		}

		public void Clear()
		{
			chart.Series.Clear();
		}

		public void Clear(string seriesName)
		{
			Series series = chart.Series.FindByName(seriesName);
			if (series == null)
				return;

			series.Points.Clear();
		}
	}
}
